Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Request ¶
type Request interface {
tmsg.Request
context.Context
// Response constructs a response to this request, with the (optional) given body. The response will share
// the request's ID, and be destined for the originator.
Response(body interface{}) Response
// A Context for the Request.
Context() context.Context
// SetContext replaces the Request's Context.
SetContext(ctx context.Context)
}
A Request is a representation of an RPC call (inbound or outbound). It extends Typhon's Request to provide a Context, and also helpers for constructing a response.
func FromTyphonRequest ¶
func NewRequest ¶
func NewRequest() Request
type Response ¶
type Response interface {
tmsg.Response
// IsError returns whether this response contains an error
IsError() bool
// SetIsError modifies whether the flag specifying whether this response contains an error
SetIsError(bool)
// Error returns the error contained within the response
Error() error
}
func FromTyphonResponse ¶
func NewResponse ¶
func NewResponse() Response
Directories
¶
| Path | Synopsis |
|---|---|
|
Package testproto is a generated protocol buffer package.
|
Package testproto is a generated protocol buffer package. |
Click to show internal directories.
Click to hide internal directories.